@@ -624,6 +624,30 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         else:
             raise KempTechApiException(get_error_msg(response))
 
+    def get_azure_ha_params(self):
+        """Get HA parameters from LM deployed on Azure
+
+        :return: Dict containing HA params
+        """
+        response = self._get('/getazurehaparams')
+        if is_successful(response):
+            data = get_data(response)
+            return data.get('AzureHA', {})
+        else:
+            raise KempTechApiException(get_error_msg(response))
+
+    def get_aws_ha_params(self):
+        """Get HA parameters from LM deployed on AWS
+
+        :return: Dict containing HA params
+        """
+        response = self._get('/getawshaparams')
+        if is_successful(response):
+            data = get_data(response)
+            return data.get('AwsHA', {})
+        else:
+            raise KempTechApiException(get_error_msg(response))
+
 
 class Geo(BaseKempAppliance):
     """GEO API object."""
